@@ -43,7 +43,7 @@ palettes <- list("#91aaa7",
 
 ltyInput <- function (id, name, val, none = TRUE) {
   selectInput(id, paste(name, 'line type'),
-              c(if(none) list('None' = 'blank'),
+              c(if (none) list('None' = 'blank'),
               list('Solid' = 'solid', 'Dotted' = 'dotted',
                    'Dashed' = 'dashed', 'Dot-Dash' = 'dotdash',
                    'Long-dash' = 'longdash', 'Two-dash' = 'twodash')),
@@ -251,10 +251,23 @@ server <- function(input, output, session) {
     fileInput <- input$datafile
     exampleFile <- system.file('TernaryApp', 'example.csv', package = 'Ternary')
     if (is.null(fileInput)) {
-      output$dataStatus <- renderText(paste(
-        "Data file not found; using example from",
-        system.file('TernaryApp', 'example.csv', package = 'Ternary')))
-      candidate <- exampleFile
+      if (exampleFile == "") {
+        ghFile <- "https://raw.githubusercontent.com/ms609/TernaryApp/master/example.csv"
+        candidate <- tryCatch({
+          read.csv(ghFile)
+          output$dataStatus <- renderText(
+            "Data / example files not found; loaded from GitHub.")
+          ghFile
+          }, warning = function (e) {
+            output$dataStatus <- renderText(
+              "Data / example files not found; could not load from GitHub.")
+            ""
+          })
+      } else {
+        output$dataStatus <- renderText(paste(
+          "Data file not found; using example from", exampleFile))
+        candidate <- exampleFile
+      }
     } else {
       candidate <- fileInput$datapath
       if (is.null(candidate)) {
@@ -589,4 +602,4 @@ server <- function(input, output, session) {
         
 }
 
-shinyApp(ui = ui, server = server)
\ No newline at end of file
+shinyApp(ui = ui, server = server)
